@@ -60,6 +60,13 @@ class ADSSClient:
         self.stamp_images = StampImagesEndpoint(self.base_url, self.auth)
         self.trilogy_images = TrilogyImagesEndpoint(self.base_url, self.auth)
         
+        if not username:
+            username = input("Username: ").strip()
+        if not password:
+            # hashed password input for security
+            import getpass
+            password = getpass.getpass("Password: ").strip()
+        
         # Authenticate if credentials provided
         if username and password:
             self.login(username, password, **kwargs)
@@ -199,6 +206,7 @@ class ADSSClient:
                       file: Optional[Union[str, BinaryIO]] = None,
                       table_name: Optional[str] = None,
                       timeout: Optional[int] = None,
+                      verbose: bool = False,
                       **kwargs) -> QueryResult:
         """
         Execute a query asynchronously and wait for the results.
@@ -214,7 +222,7 @@ class ADSSClient:
         Returns:
             QueryResult object containing the query data and metadata
         """
-        return self.queries.execute_and_wait(query_text, mode, file, table_name, timeout, **kwargs)
+        return self.queries.execute_and_wait(query_text, mode, file, table_name, timeout, verbose, **kwargs)
     
     def get_query_history(self, limit: int = 50, **kwargs) -> List[Query]:
         """
@@ -286,6 +294,24 @@ class ADSSClient:
         """
         return self.metadata.get_database_metadata(**kwargs)
     
+    def pretty_print_db_metadata(self, dbmeta: Optional[DatabaseMetadata] = None) -> None:
+        """
+        Pretty print the database metadata in a hierarchical format.
+        
+        Args:
+            dbmeta: Optional DatabaseMetadata object. If not provided, fetches current metadata.
+        """
+        if dbmeta is None:
+            dbmeta = self.get_database_metadata()
+        
+        for schema in dbmeta.schemas:
+            print(f"Schema: {schema.name}")
+            for table in schema.tables:
+                print(f"  Table: {table.name}")
+                for column in table.columns:
+                    nullable = "NULL" if column.is_nullable else "NOT NULL"
+                    print(f"    Column: {column.name} ({column.data_type}, {nullable})")
+    
     def update_profile(self, 
                      email: Optional[str] = None, 
                      full_name: Optional[str] = None,
@@ -442,7 +468,7 @@ class ADSSClient:
     
     # === Image methods ===
     
-    def get_image_collections(self, skip: int = 0, limit: int = 100, **kwargs) -> List[Dict[str, Any]]:
+    def get_collections(self, skip: int = 0, limit: int = 100, **kwargs) -> List[Dict[str, Any]]:
         """
         Get a list of accessible image collections.
         
@@ -456,7 +482,7 @@ class ADSSClient:
         """
         return self.images.get_collections(skip, limit, **kwargs)
     
-    def get_image_collection(self, collection_id: int, **kwargs) -> Dict[str, Any]:
+    def get_collection(self, collection_id: int, **kwargs) -> Dict[str, Any]:
         """
         Get a specific image collection by ID.
         
@@ -469,7 +495,7 @@ class ADSSClient:
         """
         return self.images.get_collection(collection_id, **kwargs)
     
-    def list_image_files(self, collection_id: int, skip: int = 0, limit: int = 100, 
+    def list_files(self, collection_id: int, skip: int = 0, limit: int = 100, 
                         filter_name: Optional[str] = None, filter_str: Optional[str] = None,
                         object_name: Optional[str] = None, **kwargs) -> List[Dict[str, Any]]:
         """
@@ -508,7 +534,7 @@ class ADSSClient:
         """
         return self.images.cone_search(collection_id, ra, dec, radius, filter_name, limit, **kwargs)
     
-    def download_image(self, file_id: int, output_path: Optional[str] = None, **kwargs) -> Union[bytes, str]:
+    def download_file(self, file_id: int, output_path: Optional[str] = None, **kwargs) -> Union[bytes, str]:
         """
         Download an image file.
         
