@@ -7,6 +7,7 @@ import os
 from adss.exceptions import ResourceNotFoundError
 from adss.utils import handle_response_errors
 
+import re
 
 class ImagesEndpoint:
     """
@@ -58,68 +59,6 @@ class ImagesEndpoint:
         except Exception as e:
             raise ResourceNotFoundError(f"Failed to get image collection {collection_id}: {e}")
 
-    def create_collection(self, name: str, base_path: str, description: Optional[str] = None, **kwargs) -> Dict[str, Any]:
-        url = f"{self.base_url}/adss/v1/images/collections/"
-        headers = self.auth_manager._get_auth_headers()
-        payload = {"name": name, "base_path": base_path}
-        if description:
-            payload["description"] = description
-
-        try:
-            resp = self.auth_manager.request(
-                method="POST",
-                url=url,
-                headers=headers,
-                json=payload,
-                auth_required=True,
-                **kwargs
-            )
-            handle_response_errors(resp)
-            return resp.json()
-        except Exception as e:
-            raise ResourceNotFoundError(f"Failed to create image collection: {e}")
-
-    def update_collection(self, collection_id: int, name: Optional[str] = None,
-                          description: Optional[str] = None, **kwargs) -> Dict[str, Any]:
-        url = f"{self.base_url}/adss/v1/images/collections/{collection_id}"
-        headers = self.auth_manager._get_auth_headers()
-        payload: Dict[str, Any] = {}
-        if name:
-            payload["name"] = name
-        if description is not None:
-            payload["description"] = description
-
-        try:
-            resp = self.auth_manager.request(
-                method="PUT",
-                url=url,
-                headers=headers,
-                json=payload,
-                auth_required=True,
-                **kwargs
-            )
-            handle_response_errors(resp)
-            return resp.json()
-        except Exception as e:
-            raise ResourceNotFoundError(f"Failed to update collection {collection_id}: {e}")
-
-    def delete_collection(self, collection_id: int, **kwargs) -> bool:
-        url = f"{self.base_url}/adss/v1/images/collections/{collection_id}"
-        headers = self.auth_manager._get_auth_headers()
-
-        try:
-            resp = self.auth_manager.request(
-                method="DELETE",
-                url=url,
-                headers=headers,
-                auth_required=True,
-                **kwargs
-            )
-            handle_response_errors(resp)
-            return True
-        except Exception as e:
-            raise ResourceNotFoundError(f"Failed to delete collection {collection_id}: {e}")
-
     def list_files(self,
                    collection_id: int,
                    skip: int = 0,
@@ -203,7 +142,7 @@ class ImagesEndpoint:
         url = f"{self.base_url}/adss/v1/images/files/{file_id}/download?token={self.auth_manager.token}"
 
         try:
-            resp = self.auth_manager.request(
+            resp = self.auth_manager.download(
                 method="GET",
                 url=url,
                 stream=True,
@@ -222,46 +161,10 @@ class ImagesEndpoint:
                     for chunk in resp.iter_content(8192):
                         f.write(chunk)
                 return output_path
-            return resp.content
+            return resp.read()
         except Exception as e:
             raise ResourceNotFoundError(f"Failed to download image file {file_id}: {e}")
 
-    def scan_directory(self, collection_id: int, rescan_existing: bool = False, **kwargs) -> Dict[str, Any]:
-        url = f"{self.base_url}/adss/v1/images/collections/{collection_id}/scan"
-        headers = self.auth_manager._get_auth_headers()
-        payload = {"rescan_existing": rescan_existing}
-
-        try:
-            resp = self.auth_manager.request(
-                method="POST",
-                url=url,
-                headers=headers,
-                json=payload,
-                auth_required=True,
-                **kwargs
-            )
-            handle_response_errors(resp)
-            return resp.json()
-        except Exception as e:
-            raise ResourceNotFoundError(f"Failed to scan directory: {e}")
-
-    def get_scan_status(self, job_id: str, **kwargs) -> Dict[str, Any]:
-        url = f"{self.base_url}/adss/v1/images/scan-jobs/{job_id}"
-        headers = self.auth_manager._get_auth_headers()
-
-        try:
-            resp = self.auth_manager.request(
-                method="GET",
-                url=url,
-                headers=headers,
-                auth_required=False,
-                **kwargs
-            )
-            handle_response_errors(resp)
-            return resp.json()
-        except Exception as e:
-            raise ResourceNotFoundError(f"Failed to get scan job status: {e}")
-
 
 class LuptonImagesEndpoint:
     """
@@ -301,7 +204,7 @@ class LuptonImagesEndpoint:
             payload["size"] = size
 
         try:
-            resp = self.auth_manager.request(
+            resp = self.auth_manager.download(
                 method="POST",
                 url=url,
                 headers=headers,
@@ -318,9 +221,9 @@ class LuptonImagesEndpoint:
                 output_path = os.path.join(output_path, filename)
             if output_path:
                 with open(output_path, 'wb') as f:
-                    f.write(resp.content)
-                return output_path
-            return resp.content
+                    f.write(resp.read())
+                return resp.read()
+            return resp.read()
 
         except Exception as e:
             raise ResourceNotFoundError(f"Failed to create RGB image: {e}")
@@ -374,7 +277,7 @@ class LuptonImagesEndpoint:
             payload["size"] = size
 
         try:
-            resp = self.auth_manager.request(
+            resp = self.auth_manager.download(
                 method="POST",
                 url=url,
                 headers=headers,
@@ -391,9 +294,9 @@ class LuptonImagesEndpoint:
                 output_path = os.path.join(output_path, filename)
             if output_path:
                 with open(output_path, 'wb') as f:
-                    f.write(resp.content)
-                return output_path
-            return resp.content
+                    f.write(resp.read())
+                return resp.read()
+            return resp.read()
 
         except Exception as e:
             raise ResourceNotFoundError(f"Failed to create RGB image by filenames: {e}")
@@ -405,7 +308,7 @@ class LuptonImagesEndpoint:
                                   pattern: Optional[str] = None,
                                   output_path: Optional[str] = None,
                                   **kwargs) -> Union[bytes, str]:
-        url = f"{self.base_url}/adss/v1/images/lupton_images/collections/{collection_id}/rgb_by_coordinates"
+        url = f"{self.base_url}/adss/v1/images/collections/{collection_id}/rgb_by_coordinates"
         try:
             headers = self.auth_manager._get_auth_headers()
         except:
@@ -421,7 +324,7 @@ class LuptonImagesEndpoint:
             payload["pattern"] = pattern
 
         try:
-            resp = self.auth_manager.request(
+            resp = self.auth_manager.download(
                 method="POST",
                 url=url,
                 headers=headers,
@@ -438,9 +341,9 @@ class LuptonImagesEndpoint:
                 output_path = os.path.join(output_path, filename)
             if output_path:
                 with open(output_path, 'wb') as f:
-                    f.write(resp.content)
-                return output_path
-            return resp.content
+                    f.write(resp.read())
+                return resp.read()
+            return resp.read()
 
         except Exception as e:
             raise ResourceNotFoundError(f"Failed to create RGB image by coordinates: {e}")
@@ -454,7 +357,7 @@ class LuptonImagesEndpoint:
                              pattern: Optional[str] = None,
                              output_path: Optional[str] = None,
                              **kwargs) -> Union[bytes, str]:
-        url = f"{self.base_url}/adss/v1/images/lupton_images/collections/{collection_id}/rgb_by_object"
+        url = f"{self.base_url}/adss/v1/images/collections/{collection_id}/rgb_by_object"
         try:
             headers = self.auth_manager._get_auth_headers()
         except:
@@ -476,7 +379,7 @@ class LuptonImagesEndpoint:
             payload["pattern"] = pattern
 
         try:
-            resp = self.auth_manager.request(
+            resp = self.auth_manager.download(
                 method="POST",
                 url=url,
                 headers=headers,
@@ -493,9 +396,9 @@ class LuptonImagesEndpoint:
                 output_path = os.path.join(output_path, filename)
             if output_path:
                 with open(output_path, 'wb') as f:
-                    f.write(resp.content)
-                return output_path
-            return resp.content
+                    f.write(resp.read())
+                return resp.read()
+            return resp.read()
 
         except Exception as e:
             raise ResourceNotFoundError(f"Failed to create RGB image by object: {e}")
@@ -515,7 +418,7 @@ class StampImagesEndpoint:
                      zmin: Optional[float] = None, zmax: Optional[float] = None,
                      output_path: Optional[str] = None,
                      **kwargs) -> Union[bytes, str]:
-        url = f"{self.base_url}/adss/v1/images/stamp_images/files/{file_id}/stamp"
+        url = f"{self.base_url}/adss/v1/images/collections/{file_id}/stamp"
         try:
             headers = self.auth_manager._get_auth_headers()
         except:
@@ -531,7 +434,7 @@ class StampImagesEndpoint:
             payload["zmax"] = zmax
 
         try:
-            resp = self.auth_manager.request(
+            resp = self.auth_manager.download(
                 method="POST",
                 url=url,
                 headers=headers,
@@ -549,9 +452,9 @@ class StampImagesEndpoint:
                 output_path = os.path.join(output_path, filename)
             if output_path:
                 with open(output_path, 'wb') as f:
-                    f.write(resp.content)
-                return output_path
-            return resp.content
+                    f.write(resp.read())
+                return resp.read()
+            return resp.read()
 
         except Exception as e:
             raise ResourceNotFoundError(f"Failed to create stamp from file {file_id}: {e}")
@@ -596,7 +499,7 @@ class StampImagesEndpoint:
             payload["zmax"] = zmax
 
         try:
-            resp = self.auth_manager.request(
+            resp = self.auth_manager.download(
                 method="POST",
                 url=url,
                 headers=headers,
@@ -614,9 +517,9 @@ class StampImagesEndpoint:
                 output_path = os.path.join(output_path, filename)
             if output_path:
                 with open(output_path, 'wb') as f:
-                    f.write(resp.content)
-                return output_path
-            return resp.content
+                    f.write(resp.read())
+                return resp.read()
+            return resp.read()
 
         except Exception as e:
             raise ResourceNotFoundError(f"Failed to create stamp from file {filename}: {e}")
@@ -646,7 +549,7 @@ class StampImagesEndpoint:
             payload["pattern"] = pattern
 
         try:
-            resp = self.auth_manager.request(
+            resp = self.auth_manager.download(
                 method="POST",
                 url=url,
                 headers=headers,
@@ -664,31 +567,49 @@ class StampImagesEndpoint:
                 output_path = os.path.join(output_path, filename)
             if output_path:
                 with open(output_path, 'wb') as f:
-                    f.write(resp.content)
-                return output_path
-            return resp.content
+                    f.write(resp.read())
+                return resp.read()
+            return resp.read()
 
         except Exception as e:
             raise ResourceNotFoundError(f"Failed to create stamp by coordinates: {e}")
 
-    def create_stamp_by_object(self,
-                               collection_id: int, object_name: str,
-                               filter_name: str, ra: float, dec: float, size: float,
-                               size_unit: str = "arcmin", format: str = "fits",
-                               zmin: Optional[float] = None, zmax: Optional[float] = None,
-                               pattern: Optional[str] = None,
-                               output_path: Optional[str] = None,
-                               **kwargs) -> Union[bytes, str]:
-        url = f"{self.base_url}/adss/v1/images/stamp_images/collections/{collection_id}/stamp_by_object"
+    # TODO: Apply the same pattern of this functions to all download functions in this file
+    def create_stamp_by_object(
+        self,
+        collection_id: int,
+        object_name: str,
+        filter_name: str,
+        ra: float,
+        dec: float,
+        size: float,
+        size_unit: str = "arcmin",
+        format: str = "fits",
+        zmin: Optional[float] = None,
+        zmax: Optional[float] = None,
+        pattern: Optional[str] = None,
+        output_path: Optional[str] = None,
+        **kwargs
+    ) -> Union[bytes, str]:
+        url = f"{self.base_url}/adss/v1/images/collections/{collection_id}/stamp_by_object"
+
+        # Build headers (auth if available), prefer identity for big binaries
         try:
             headers = self.auth_manager._get_auth_headers()
-        except:
-            headers = {"Accept": "image/png" if format == "png" else "application/fits"}
+        except Exception:
+            headers = {}
+        headers.setdefault("Accept", "image/png" if format == "png" else "application/fits")
+        headers.setdefault("Accept-Encoding", "identity")
 
+        # Payload
         payload: Dict[str, Any] = {
-            "object_name": object_name, "filter_name": filter_name,
-            "ra": ra, "dec": dec, "size": size,
-            "size_unit": size_unit, "format": format
+            "object_name": object_name,
+            "filter_name": filter_name,
+            "ra": ra,
+            "dec": dec,
+            "size": size,
+            "size_unit": size_unit,
+            "format": format,
         }
         if zmin is not None:
             payload["zmin"] = zmin
@@ -697,8 +618,9 @@ class StampImagesEndpoint:
         if pattern:
             payload["pattern"] = pattern
 
+        # Download bytes in one go (no Response object leaked to callers)
         try:
-            resp = self.auth_manager.request(
+            data = self.auth_manager.download_bytes(
                 method="POST",
                 url=url,
                 headers=headers,
@@ -706,23 +628,40 @@ class StampImagesEndpoint:
                 auth_required=False,
                 **kwargs
             )
-            handle_response_errors(resp)
-
-            cd = resp.headers.get('Content-Disposition', '')
-            ext = "fits" if format == "fits" else "png"
-            filename = cd.split('filename=')[1].strip('"') if 'filename=' in cd else f"stamp.{ext}"
-
-            if output_path and os.path.isdir(output_path):
-                output_path = os.path.join(output_path, filename)
-            if output_path:
-                with open(output_path, 'wb') as f:
-                    f.write(resp.content)
-                return output_path
-            return resp.content
-
         except Exception as e:
             raise ResourceNotFoundError(f"Failed to create stamp by object: {e}")
 
+        # If no output_path => return bytes
+        if not output_path:
+            return data
+
+        # If writing to disk, synthesize a stable filename
+        ext = "fits" if format == "fits" else "png"
+
+        # sanitize components for filesystem safety
+        def _safe(s: str) -> str:
+            s = s.strip()
+            s = re.sub(r"\s+", "_", s)           # spaces -> underscores
+            s = re.sub(r"[^A-Za-z0-9._\-+]", "", s)  # drop weird chars
+            return s or "unknown"
+
+        obj = _safe(object_name)
+        filt = _safe(filter_name)
+        size_str = f"{size:g}{size_unit}"
+
+        filename = f"stamp_{obj}_{filt}_{size_str}.{ext}"
+
+        # If output_path is a dir, append filename; otherwise treat as full path
+        final_path = output_path
+        if os.path.isdir(final_path):
+            final_path = os.path.join(final_path, filename)
+
+        os.makedirs(os.path.dirname(final_path) or ".", exist_ok=True)
+        with open(final_path, "wb") as f:
+            f.write(data)
+
+        return final_path
+
 
 class TrilogyImagesEndpoint:
     """
@@ -763,7 +702,7 @@ class TrilogyImagesEndpoint:
             payload["size"] = size
 
         try:
-            resp = self.auth_manager.request(
+            resp = self.auth_manager.download(
                 method="POST",
                 url=url,
                 headers=headers,
@@ -780,9 +719,9 @@ class TrilogyImagesEndpoint:
                 output_path = os.path.join(output_path, filename)
             if output_path:
                 with open(output_path, 'wb') as f:
-                    f.write(resp.content)
-                return output_path
-            return resp.content
+                    f.write(resp.read())
+                return resp.read()
+            return resp.read()
 
         except Exception as e:
             raise ResourceNotFoundError(f"Failed to create Trilogy RGB image: {e}")
@@ -812,7 +751,7 @@ class TrilogyImagesEndpoint:
             payload["pattern"] = pattern
 
         try:
-            resp = self.auth_manager.request(
+            resp = self.auth_manager.download(
                 method="POST",
                 url=url,
                 headers=headers,
@@ -829,9 +768,9 @@ class TrilogyImagesEndpoint:
                 output_path = os.path.join(output_path, filename)
             if output_path:
                 with open(output_path, 'wb') as f:
-                    f.write(resp.content)
+                    f.write(resp.read())
                 return output_path
-            return resp.content
+            return resp.read()
 
         except Exception as e:
             raise ResourceNotFoundError(f"Failed to create Trilogy RGB image by coordinates: {e}")
@@ -868,7 +807,7 @@ class TrilogyImagesEndpoint:
             payload["pattern"] = pattern
 
         try:
-            resp = self.auth_manager.request(
+            resp = self.auth_manager.download(
                 method="POST",
                 url=url,
                 headers=headers,
@@ -885,9 +824,9 @@ class TrilogyImagesEndpoint:
                 output_path = os.path.join(output_path, filename)
             if output_path:
                 with open(output_path, 'wb') as f:
-                    f.write(resp.content)
-                return output_path
-            return resp.content
+                    f.write(resp.read())
+                return resp.read()
+            return resp.read()
 
         except Exception as e:
             raise ResourceNotFoundError(f"Failed to create Trilogy RGB image by object: {e}")
\ No newline at end of file
